<!-- # Team UCSC 2022 Software Tool

If you team competes in the [**Software & AI** track](https://competition.igem.org/participation/tracks) or wants to
apply for the [**Best Software Tool** Award](https://competition.igem.org/judging/awards), you **MUST** host all the
code of your team's software tool in this repository, `main` branch. By the **Wiki Freeze**, a
[release](https://docs.gitlab.com/ee/user/project/releases/) will be automatically created as the judging artifact of
this software tool. You will be able to keep working on your software after the Grand Jamboree.

> If your team does not have any software tool, you can totally ignore this repository. If left unchanged, this
repository will be automatically deleted by the end of the season. -->

# UCSC iGEM 2022 Modeling Tool
## Description
Our goal is to create an affordable and easily accessible Type 2 Diabetes medication. Diabetes Mellitus affects roughly 1 in 10 people globally and is found in two main forms: Type 
1 and Type 2. 

Type 2 Diabetes (T2D) comprises 95% of all diabetes cases and is primarily a result of insulin resistance. The population affected by diabetes is projected to increase by 50% over 
the next 20 years, and even more so in countries that do not have medical infrastructure equipped to offer adequate treatment. 
Moreover, the burden of diabetes is disproportionately borne by lower income groups.

Chronic complications associated with T2D include heart failure, kidney disease, limb amputations, blindness, and neuropathy. Of all associated complications, 50-85% are 
preventable by treatment and medication. 

Since we believe that healthcare is a human right, our team wanted to pursue a project using the resources and privileges we have to make a global human impact among resource
constrained communities. Our goal was to tackle the issue of inadequate accessibility of diabetic treatments and hoped to improve human health, especially in resource sontrained 
communities.

We felt having a mathematical model would benefit future developments of this project as it provides an estimate for the Competitive Binding and Dosage Effect models. 
However, we would need to optimize our graphs depending on the host organism. We specifically chose to pursue Competitive Binding as it would provide us with the best estimate for 
the amount of insulin released given just Ex-4 and GLP-1 in a system. In doing so, we were able to successfully visualize the maximum rates of production, and in turn helped us
when designing the Dosage Effect Model. As for the reason behind the Dosage Effect model, we wanted to have some sort of visual to help determine the amount of Insulin produced
given a concentration of Ex-4. Upon further implementation of this project and experimental data from a pancreatic cell test, we will be able to fine tune these models and have a more robust model for predicting the concentration of Ex-4 bound to the receptor and the resulting insulin production.


If you are curious about our project, you can find more about us on our website: https://2022.igem.wiki/ucsc/index.html

## Installation
Python3 - We used version 3.10.4 which requires Windows 8 and above   

(1) Jupyter Notebook: https://jupyter.org/install 

Matlab - We used R2022a (System requirements are found: https://www.mathworks.com/support/requirements/matlab-system-requirements.html) 

(1) Simbio - Download: https://simbio.com/preview-installer/ 

## Usage

For further information about any of these models, visit our modeling page for more informatin: https://2022.igem.wiki/ucsc/model

Competitive Binding Model: 

The main focus of this model, in the context of our project, is to compare how well exendin-4 (Ex-4) will bind to the glucagon-like peptide 1
receptor (GLP-1 R) when in the presence of the native glucagon-like peptide 1 (GLP-1) in vivo. 
This model assumes binding contributes to the overall effect and is capable of being used for any competitive binding system that one may wish to compare. 
Therefore, we wanted to understand each peptide's binding affinity because it will demonstrate the overall effectiveness 
of our recombinant Ex-4. We used fractional occupancy to represent competitive binding as it tells us the concentration of receptors bound to their respective ligand.
In this model we are representing the efficacy of a drug/ligand by the total number of receptor-ligand complexes formed. 
In other words, fractional occupancy is a comparison between the efficacy of the drug and the total maximum efficacy.   
The derivation is shown here: https://tinyurl.com/igemfocc

Parameters Needed: 

(1) Kd1 = Dissociation Constant for labeled ligand (In our case: Ex-4)

(2) Kd2 = Dissociation Constant for competitor (In our case: GLP-1) 

(3) L1 = Concentration of the first ligand (In our case: Ex-4)

(4) L2 = Concentration of the second ligand (In our case: native GLP-1) 


In our model, we considered Kd1 to be Ex-4 because our model is made for the purpose of gaining a better understanding 
of how our recombinant protein will interact in a system. As of our most recent progress, we are assuming that no external factors 
except native GLP-1 will affect our Ex-4 because we are planning to conduct tests in pancreatic beta cells. Naturally, the competitor to 
Ex-4 would be the GLP-1. As we have not progressed far enough to conduct the pancreatic cell tests, we used literature values to get an estimate 
of the expected values. Once we are able to test and get experimental data through the pancreatic beta cell test, we will be replacing these values. 
This model is used to both conceptualize and represent our actual data. 

All of this is adaptable. For future users who are looking for ways to represent competitve binding of two ligands, this model is adaptable to the ligand and competitor users are 
interested in. As long as users adjust the Kd values (generally found through literature), they will be able to produce a fractional occupancy semilogx graph 
and the point where the ligand (of interest) concentration has 50% occupancy. If users decide to adjust the equation (we labeled as Focc
Cell 8 Line 22), it will still find and plot the point at which concentration is at 50%. 50% in PKD models are important points because it is where there is the largest effect at the smallest concentration of ligand. This is because in binding kinetic theory, the binding of a ligand directly affects the effects of the ligand. 
 
-----------------------
Dosage Effect Model: 

The purpose of this model is to visually represent the correlation between a given dosage of Ex-4 and its pharmacological effect 
in vivo. Originally, we planned on conducting pancreatic beta cell tests before the Wiki-Freeze. As the pancreatic beta cell test does not contain 
GLP-1, we produced a new model that only looks at the effect of Exendin-4. We used an efficacy equation because it would tell us the maximum insulin production in relation to the 
concentration of Exendin-4 in the system. The derivation for the efficacy equation is shown here: https://tinyurl.com/UCSCigemDEM. This model is essentially showing the same data as the 
competitive binding model, except it does not account for GLP-1. This model is also adjustable to users. For users that do not care about competitive binding and are only curious about the 
effect of their ligand can use this model. All that needs to be changed is the EC_50 and E_max values of the ligand of interest. The program will graph the efficacy graph and plot the point at which efficiacy is 50%.

Parameters Needed: 

(1) E_max = Technically an arbitrary constant, the meaning of this constant will change depending on what drug you are looking at.
(In our case we are looking at the maximum insulin production, which is when the most amount of Ex-4 are bound to the receptor)

(2) EC_50 = Value at which 50% of the receptors have bound to the ligands (In our case: Ex-4*GLP-1 R complex)

(3) C = Concentration of the ligand (In our case: Ex-4)

-----------------------
Protein Production Model:

In collabartion wtih Stony Brook University, we created a protein production model. We used the central dogma of biology to create this model as it follows the biological pathway from DNA to protein. While current file that is uploaded on Gitlab is representative of Stony Brook's protein, Protein S, all of this is adjustable. Once users download the project, open up Simbio, users can adjust the model based off of their dissociation and binding of their protein of interest.  
 

## Contributing to this Project

We are open to contributions from anyone who is working with protein production. We request that any additions made 
to the project be written in either Simbio or Python as majority of our code is in these two languages. 

To run our code, if you are using Windows, open Command Prompt (cmd) and type in "jupyter notebook". This should 
open up your files on juypter, allowing for you to type in edit directly on your local repository.  

For Symbio, while the version likely does not matter, to prevent errors be sure to use MatLab R2022a,
open the extension to Symbio then open the file. This should give you direct access to the current copy on the Gitlab. 


## Authors and acknowledgment
The code provided above was written by the UCSC iGEM 2022 Modeling Team: Jonathan Zau, Joanne Shen, Vidhata Singh, and our mentor/TA Eric Malekos. 

We would like to thank our mentor/TA Eric for taking the time off of his busy schedule to guide us through the mathamtical 
and scientific reasonings behind our models, as well as mentor us in programming. We would like to thank Professor Michael Stone
for discussing and providing insight on the biophysics behind our models and relavance to our wet lab project. Also, we would 
like to thank Professor David Bernick, our PI, for continously challenging us and teaching us perseverance when hit with 
different kinds of roadblocks.

